@@ -30,7 +30,11 @@ Edit History:
 #include <errno.h>
 #include <string.h>
 #ifndef _OSK
+#ifdef _MACOSX
+#include <termios.h>
+#else
 #include <termio.h>
+#endif
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/ipc.h>
